# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/lorem/zh_TW/__init__.py

lorem_word_connector_zh_tw <- ""
lorem_word_list_zh_tw <- c(
  "\u4e00\u500b",
  "\u6211\u5011",
  "\u6642\u9593",
  "\u53f0\u7063",
  "\u53ef\u4ee5",
  "\u516c\u53f8",
  "\u6c92\u6709",
  "\u4fe1\u606f",
  "\u4e0b\u8f09",
  "\u8edf\u9ad4",
  "\u6ce8\u518a",
  "\u81ea\u5df1",
  "\u7522\u54c1",
  "\u5de5\u4f5c",
  "\u8ad6\u58c7",
  "\u4f01\u696d",
  "\u9019\u500b",
  "\u4ed6\u5011",
  "\u7ba1\u7406",
  "\u5df2\u7d93",
  "\u554f\u984c",
  "\u5167\u5bb9",
  "\u4f7f\u7528",
  "\u9032\u884c",
  "\u5e02\u5834",
  "\u670d\u52d9",
  "\u5982\u679c",
  "\u7cfb\u7d71",
  "\u6280\u8853",
  "\u767c\u5c55",
  "\u73fe\u5728",
  "\u4f5c\u8005",
  "\u5c31\u662f",
  "\u7db2\u7d61",
  "\u63d0\u4f9b",
  "\u76f8\u95dc",
  "\u6211\u7684",
  "\u6587\u7ae0",
  "\u65b9\u5f0f",
  "\u96fb\u8a71",
  "\u767c\u8868",
  "\u6240\u6709",
  "\u6642\u5019",
  "\u56e0\u70ba",
  "\u53f0\u5317",
  "\u6709\u9650",
  "\u516c\u53f8",
  "\u4ec0\u9ebc",
  "\u9084\u662f",
  "\u958b\u59cb",
  "\u672c\u7ad9",
  "\u767c\u5e03",
  "\u81ea\u5df1",
  "\u652f\u6301",
  "\u5728\u7dda",
  "\u570b\u5bb6",
  "\u751f\u6d3b",
  "\u806f\u7cfb",
  "\u7a4d\u5206",
  "\u4e3b\u984c",
  "\u6240\u4ee5",
  "\u4e0d\u80fd",
  "\u7684\u4eba",
  "\u4e0a\u6d77",
  "\u4e2d\u5fc3",
  "\u4e16\u754c",
  "\u6e38\u6232",
  "\u9700\u8981",
  "\u50f9\u683c",
  "\u7528\u6236",
  "\u901a\u904e",
  "\u8981\u6c42",
  "\u4e0d\u662f",
  "\u514d\u8cbb",
  "\u500b\u4eba",
  "\u4f46\u662f",
  "\u5730\u5740",
  "\u7db2\u7ad9",
  "\u60c5\u6cc1",
  "\u6700\u540e",
  "\u8a2d\u8a08",
  "\u540c\u6642",
  "\u9019\u4e9b",
  "\u6d3b\u52d5",
  "\u624b\u6a5f",
  "\u63a8\u85a6",
  "\u4e00\u4e9b",
  "\u4e3b\u8981",
  "\u5927\u5bb6",
  "\u767c\u73fe",
  "\u76ee\u524d",
  "\u6587\u4ef6",
  "\u4f60\u7684",
  "\u4e0d\u904e",
  "\u8a55\u8ad6",
  "\u751f\u7522",
  "\u7f8e\u570b",
  "\u5716\u7247",
  "\u7d93\u6fdf",
  "\u529f\u80fd",
  "\u570b\u969b",
  "\u7684\u662f",
  "\u9078\u64c7",
  "\u5176\u4ed6",
  "\u9019\u6a23",
  "\u6703\u54e1",
  "\u74b0\u5883",
  "\u4f86\u81ea",
  "\u65e5\u671f",
  "\u6210\u70ba",
  "\u4ed6\u7684",
  "\u6700\u65b0",
  "\u5c08\u696d",
  "\u4e00\u4e0b",
  "\u4eba\u54e1",
  "\u4efb\u4f55",
  "\u6559\u80b2",
  "\u8cc7\u6599",
  "\u72c0\u614b",
  "\u90fd\u662f",
  "\u9ede\u64ca",
  "\u70ba\u4e86",
  "\u4e0d\u6703",
  "\u51fa\u73fe",
  "\u77e5\u9053",
  "\u793e\u6703",
  "\u540d\u7a31",
  "\u800c\u4e14",
  "\u4ecb\u7d39",
  "\u97f3\u6a02",
  "\u7b49\u7d1a",
  "\u53ef\u80fd",
  "\u9019\u7a2e",
  "\u5efa\u8a2d",
  "\u670b\u53cb",
  "\u96d6\u7136",
  "\u96fb\u5b50",
  "\u8cc7\u6e90",
  "\u770b\u5230",
  "\u7cbe\u83ef",
  "\u96fb\u5f71",
  "\u5982\u4f55",
  "\u65b0\u805e",
  "\u95b1\u8b80",
  "\u5b89\u5168",
  "\u5168\u570b",
  "\u96bb\u6709",
  "\u56de\u5fa9",
  "\u5927\u5b78",
  "\u5b78\u751f",
  "\u5b78\u7fd2",
  "\u95dc\u65bc",
  "\u9805\u76ee",
  "\u4e0d\u540c",
  "\u4ee5\u53ca",
  "\u6709\u95dc",
  "\u90a3\u9ebc",
  "\u958b\u767c",
  "\u9084\u6709",
  "\u96bb\u662f",
  "\u975e\u5e38",
  "\u7814\u7a76",
  "\u5ee3\u544a",
  "\u9996\u9801",
  "\u65b9\u6cd5",
  "\u5e0c\u671b",
  "\u5730\u65b9",
  "\u4e5f\u662f",
  "\u55ae\u4f4d",
  "\u600e\u9ebc",
  "\u61c9\u8a72",
  "\u4eca\u5929",
  "\u4ee5\u4e0a",
  "\u66f4\u65b0",
  "\u5e16\u5b50",
  "\u986f\u793a",
  "\u80fd\u529b",
  "\u96fb\u8166",
  "\u8a18\u8005",
  "\u67e5\u770b",
  "\u4f4d\u7f6e",
  "\u4e0d\u8981",
  "\u7531\u65bc",
  "\u7121\u6cd5",
  "\u8a73\u7d30",
  "\u6295\u8cc7",
  "\u662f\u4e00",
  "\u4e00\u822c",
  "\u9032\u5165",
  "\u767c\u751f",
  "\u9019\u88e1",
  "\u611f\u89ba",
  "\u66f4\u591a",
  "\u4f60\u5011",
  "\u7684\u8a71",
  "\u8d77\u4f86",
  "\u6a19\u51c6",
  "\u4e00\u6a23",
  "\u8a8d\u70ba",
  "\u5973\u4eba",
  "\u90a3\u500b",
  "\u8a2d\u5099",
  "\u641c\u7d22",
  "\u4e4b\u540e",
  "\u7136\u540e",
  "\u5b78\u6821",
  "\u92b7\u552e",
  "\u7d44\u7e54",
  "\u8aaa\u660e",
  "\u63d0\u9ad8",
  "\u70ba\u4ec0",
  "\u4f5c\u54c1",
  "\u6216\u8005",
  "\u559c\u6b61",
  "\u6771\u897f",
  "\u65b9\u9762",
  "\u7c21\u4ecb",
  "\u5fc5\u9808",
  "\u7d93\u71df",
  "\u79d1\u6280",
  "\u4f5c\u70ba",
  "\u5176\u4e2d",
  "\u904b\u884c",
  "\u5de5\u7a0b",
  "\u89e3\u6c7a",
  "\u64cd\u4f5c",
  "\u7d93\u9a57",
  "\u5730\u5340",
  "\u91cd\u8981",
  "\u76f4\u63a5",
  "\u767b\u9304",
  "\u5408\u4f5c",
  "\u7d50\u679c",
  "\u5f71\u97ff",
  "\u9019\u662f",
  "\u884c\u696d",
  "\u5c0d\u65bc",
  "\u8868\u793a",
  "\u7a0b\u5e8f",
  "\u5305\u62ec",
  "\u7559\u8a00",
  "\u898f\u5b9a",
  "\u8655\u7406",
  "\u7537\u4eba",
  "\u5404\u7a2e",
  "\u90e8\u9580",
  "\u6578\u64da",
  "\u5177\u6709",
  "\u5546\u54c1",
  "\u7cfb\u5217",
  "\u5927\u5c0f",
  "\u56e0\u6b64",
  "\u95dc\u7cfb",
  "\u53ef\u662f",
  "\u6bd4\u8f03",
  "\u6587\u5316",
  "\u4e00\u76f4",
  "\u6cd5\u5f8b",
  "\u9019\u9ebc",
  "\u60a8\u7684",
  "\u57ce\u5e02",
  "\u5206\u6790",
  "\u57fa\u672c",
  "\u6700\u5927",
  "\u985e\u5225",
  "\u5169\u500b",
  "\u65e5\u672c",
  "\u5f97\u5230",
  "\u4e00\u6b21",
  "\u7e7c\u7e8c",
  "\u6210\u529f",
  "\u5979\u7684",
  "\u8cac\u4efb",
  "\u6df1\u5733",
  "\u696d\u52d9",
  "\u6b61\u8fce",
  "\u52a0\u5165",
  "\u80fd\u5920",
  "\u89ba\u5f97",
  "\u90e8\u5206",
  "\u4e2d\u6587",
  "\u6839\u64da",
  "\u4eba\u6c11",
  "\u653f\u5e9c",
  "\u63a7\u5236",
  "\u5176\u5be6",
  "\u4e4b\u9593",
  "\u4e00\u7a2e",
  "\u5a01\u671b",
  "\u5be6\u73fe",
  "\u8a9e\u8a00",
  "\u51fa\u4f86",
  "\u8b1d\u8b1d",
  "\u793e\u5340",
  "\u54c1\u724c",
  "\u662f\u5426",
  "\u5de5\u5177",
  "\u5b8c\u5168",
  "\u6c7a\u5b9a",
  "\u5f88\u591a",
  "\u7db2\u4e0a",
  "\u4e8b\u60c5",
  "\u4eca\u5e74",
  "\u570b\u5167",
  "\u4ee5\u540e",
  "\u5236\u4f5c",
  "\u700f\u89bd",
  "\u904e\u7a0b",
  "\u5b8c\u6210",
  "\u985e\u578b",
  "\u4f86\u6e90",
  "\u8cea\u91cf",
  "\u6709\u4e9b",
  "\u4e00\u8d77",
  "\u7576\u7136",
  "\u6c7d\u8eca",
  "\u4e00\u9ede",
  "\u5e6b\u52a9",
  "\u589e\u52a0",
  "\u6b77\u53f2",
  "\u4ee5\u4e0b",
  "\u4e0d\u65b7",
  "\u61c9\u7528",
  "\u90a3\u4e9b",
  "\u5bc6\u78bc",
  "\u8a08\u5283",
  "\u5982\u6b64",
  "\u6b21\u6578",
  "\u5230\u4e86",
  "\u64c1\u6709",
  "\u5b69\u5b50",
  "\u539f\u56e0",
  "\u53c3\u52a0",
  "\u96bb\u8981",
  "\u5831\u544a",
  "\u7576\u524d",
  "\u5ba2\u6236",
  "\u6b63\u5728",
  "\u6ce8\u610f",
  "\u6a19\u984c",
  "\u7a7a\u9593",
  "\u4e00\u5b9a",
  "\u4e00\u5207",
  "\u7279\u5225",
  "\u5168\u90e8",
  "\u51c6\u5099"
)

#' Lorem provider Chinese (Taiwan)
#'
#' Methods for Lorem Ipsum generation.
#' Lorem Ipsum is a placeholder text commonly used to demonstrate the visual
#' form of a document or a typeface without relying on meaningful content.
#' @family zh
#' @family TW
#' @export
#' @examples
#' x <- LoremProvider_zh_TW$new()
#' x$word()
#' x$words(3)
#' x$words(6)
#' x$sentence()
#' x$paragraph()
#' x$paragraphs(3)
#' cat(x$paragraphs(6), sep = "\n")
#' x$text(19)
#' x <- LoremProvider_zh_TW$new(word_connector = " --- ")
#' x$paragraph(4)
LoremProvider_zh_TW <- R6::R6Class(
  inherit = LoremProvider,
  "LoremProvider_zh_TW",
  private = list(
    word_list = lorem_word_list_zh_tw,
    word_connector = lorem_word_connector_zh_tw,
    locale_ = "zh_TW"
  )
)
